BuiltinCallISpan

Struct BuiltinCallISpan 

pub struct BuiltinCallISpan {
    pub name: SymbolKey,
    pub name_pos: LineCol,
    pub upcall_index: usize,
    pub nargs: usize,
}
Components of a builtin command call.

Fields

name: SymbolKey

Name of the builtin to call.

name_pos: LineCol

Position of the name.

upcall_index: usize

Runtime index to execute this call.

nargs: usize

Number of arguments on the stack for the call.

The arguments in the stack are interspersed with the separators used to separate them from each other because those separators have meaning.