pub fn compile(input: &mut dyn Read, syms: &Symbols) -> Result<Image>Expand description
Compiles a collection of statements into an image ready for execution.
syms is a reference to the execution symbols and is used to obtain the names of the callables
that exist in the virtual machine.