pub enum GlobalDefKind {
Scalar {
etype: ExprType,
initial_value: Option<ConstantDatum>,
},
Array {
subtype: ExprType,
dimensions: Vec<usize>,
},
}Expand description
Kind of a pre-defined global variable.
Variants
Scalar
A scalar (non-array) variable.
Fields

initial_value: Option<ConstantDatum>Initial value for the variable. If None, the variable is initialized to its default
value: 0 for numeric types and an empty string for Text. The type of the datum
must match etype.
Array
A multidimensional array with the given element type and fixed dimension sizes.
Each dimension size must be positive and must fit in a u16.