pub enum SingularArgSyntax {
RequiredValue(RequiredValueSyntax, ArgSepSyntax),
RequiredRef(RequiredRefSyntax, ArgSepSyntax),
OptionalValue(OptionalValueSyntax, ArgSepSyntax),
AnyValue(AnyValueSyntax, ArgSepSyntax),
}Expand description
Syntax specification for a non-repeated argument.
Every item in this enum is composed of a struct that provides the details on the parameter and a struct that provides the details on how this parameter is separated from the next.
Variants
RequiredValue(RequiredValueSyntax, ArgSepSyntax)
A required scalar value with the syntax details and the separator that follows.
RequiredRef(RequiredRefSyntax, ArgSepSyntax)
A required reference with the syntax details and the separator that follows.
OptionalValue(OptionalValueSyntax, ArgSepSyntax)
An optional scalar value with the syntax details and the separator that follows.
AnyValue(AnyValueSyntax, ArgSepSyntax)
A required scalar value of any type with the syntax details and the separator that follows.