pub enum StopReason<'a> {
End(ExitCode),
Eof,
Exception(LineCol, String),
UpcallAsync(UpcallHandler<'a>),
Yield,
}Expand description
Representation of termination states from program execution.
Variants
End(ExitCode)
Execution terminated due to an END instruction.
Eof
Execution terminated due to natural fallthrough.
Exception(LineCol, String)
Execution stopped due to an instruction-level exception.
UpcallAsync(UpcallHandler<'a>)
Execution stopped due to an asynchronous upcall that requires service from the caller.
Yield
Execution stopped to yield control back to the caller.