UpcallError

Enum UpcallError 

pub enum UpcallError {
    Argument(LineCol, String),
    Eval(LineCol, String),
    IoError(LineCol, String),
    Precondition(LineCol, String),
    Syntax(LineCol, String),
}
Error type for uncaught upcall failures.

This should be the same as CallError but with all error variants annotated with a position.

Variants



Argument(LineCol, String)

Invalid callable argument at a given source location.



Eval(LineCol, String)

Runtime evaluation error at a given source location.



IoError(LineCol, String)

I/O error at a given source location.



Precondition(LineCol, String)

Callable precondition failure at a given source location.



Syntax(LineCol, String)

Runtime syntax error at a specific source location.

Implementations

Source

impl UpcallError

pub fn parts(&self) -> (LineCol, String)

Returns the source position and message of this error.