pub struct AnyValueSyntax {
pub name: Cow<'static, str>,
pub allow_missing: bool,
}Expand description
Syntax specification for a parameter that accepts any scalar type.
Fields
name: Cow<'static, str>The name of the parameter for help purposes.
allow_missing: boolWhether to allow the parameter to not be present or not. Can only be true for commands.