Compiler

Struct Compiler 

pub struct Compiler { /* private fields */ }
Compiler context.

This exists to support incremental compilation by keeping state and appending code to the image being built, which is useful in REPL scenarios.

Implementations

Source

impl Compiler

pub fn new( upcalls: &HashMap<SymbolKey, Rc<dyn Callable>>, global_defs: &[GlobalDef], ) -> Result<Self, Error>

Creates a new compiler instance.

global_defs provides pre-defined global variables visible to the compiled program.

upcalls contains the metadata of all built-in callables that the compiled code can use.

pub fn compile(self, input: &mut dyn Read) -> Result<Image, Error>

Compiles a chunk of code.

pub fn compile_more( &mut self, image: &mut Image, input: &mut dyn Read, ) -> Result<(), Error>

Compiles a chunk of code and appends it to image.