RegisterRef

Struct RegisterRef 

pub struct RegisterRef<'a, 'vm> {
    pub vtype: ExprType,
    /* private fields */
}
An immutable reference to a variable (register) in the register file, carrying its type for runtime validation of dereference operations.

Fields

vtype: ExprType

The type of the value pointed to.

Implementations

Source

impl<'a, 'vm> RegisterRef<'a, 'vm>

pub fn deref_boolean(&self) -> bool

Dereferences this register reference as a boolean.

pub fn deref_double(&self) -> f64

Dereferences this register reference as a double.

pub fn deref_integer(&self) -> i32

Dereferences this register reference as an integer.

pub fn deref_string(&self) -> &str

Dereferences this register reference as a string.

pub fn array_dimensions(&self) -> &[usize]

Dereferences this register reference as an array and returns its dimensions.