Scope

Struct Scope 

pub struct Scope<'a> { /* private fields */ }
Arguments provided to a callable during its execution.

Implementations

Source

impl<'a> Scope<'a>

pub fn data(&self) -> &[Option<ConstantDatum>]

Returns DATA values captured from the compiled source in encounter order.

pub fn nargs(&self) -> usize

Returns the total number of argument register slots.

pub fn get_pos(&self, arg: u8) -> LineCol

Returns the source position of the argument at arg.

arg is the logical argument index, matching the N in scope.get_*(N).

pub fn get_type(&self, arg: u8) -> VarArgTag

Gets the type tag of the argument at arg.

pub fn get_boolean(&self, arg: u8) -> bool

Gets the boolean value of the argument at arg.

pub fn get_double(&self, arg: u8) -> f64

Gets the double value of the argument at arg.

pub fn get_integer(&self, arg: u8) -> i32

Gets the integer value of the argument at arg.

pub fn get_ref(&self, arg: u8) -> RegisterRef<'_, 'a>

Gets an immutable register reference from the argument at arg.

pub fn get_mut_ref(&mut self, arg: u8) -> RegisterRefMut<'_, 'a>

Gets a mutable register reference from the argument at arg.

pub fn get_string(&self, arg: u8) -> &str

Gets the string value of the argument at arg.

pub fn last_error(&self) -> Option<(LineCol, &str)>

Returns the last error stored in the VM, if any.

pub fn return_boolean(self, b: bool) -> CallResult<()>

Sets the return value of the function to b.

Always returns success. The returned value is only to support the idiomatic invocation return scope.return_boolean(...).

pub fn return_double(self, d: f64) -> CallResult<()>

Sets the return value of the function to d.

Always returns success. The returned value is only to support the idiomatic invocation return scope.return_double(...).

pub fn return_integer(self, i: i32) -> CallResult<()>

Sets the return value of the function to i.

Always returns success. The returned value is only to support the idiomatic invocation return scope.return_integer(...).

pub fn return_string<S: Into<String>>(self, s: S) -> CallResult<()>

Sets the return value of the function to s.

Always returns success. The returned value is only to support the idiomatic invocation return scope.return_string(...).