The EndBASIC core language parser, compiler, and virtual machine.
Structs
- AnyValue
Syntax - Syntax specification for a parameter that accepts any scalar type.
- Callable
Metadata - Representation of a callable’s metadata.
- Callable
Metadata Builder - Builder pattern for constructing a callable’s metadata.
- Compiler
- Compiler context.
- Exit
Code - Program exit code carried by the
ENDinstruction. - Global
Def - Descriptor for a single global variable to be pre-defined before compilation.
- Image
- Representation of a compiled EndBASIC program.
- Invalid
Exit Code Error - Error to indicate an invalid
ENDexit code. - Limits
- Limits for VM execution resources.
- LineCol
- A position within a source stream, represented as line and column numbers.
- Optional
Value Syntax - Syntax specification for an optional scalar parameter.
- Register
Ref - An immutable reference to a variable (register) in the register file, carrying its type for runtime validation of dereference operations.
- Register
RefMut - A mutable reference to a variable (register) in the register file, carrying its type for runtime validation of dereference and set operations.
- Repeated
Syntax - Syntax specification for a repeated parameter.
- Required
RefSyntax - Syntax specification for a required reference parameter.
- Required
Value Syntax - Syntax specification for a required scalar parameter.
- Scope
- Arguments provided to a callable during its execution.
- Symbol
Key - The key of a symbol in the symbols table.
- U24
- An unsigned integer constrained to 24 bits.
- Vm
- Virtual machine for EndBASIC program execution.
Enums
- ArgSep
- Types of separators between arguments to a
BuiltinCall. - ArgSep
Syntax - Specifies the expected argument separator in a callable’s syntax.
- Call
Error - Error types for callable execution.
- Compiler
Error - Errors that can occur during compilation.
- Constant
Datum - A typed scalar value, used both in the compile-time constant pool and as a return value when inspecting global variables after execution.
- Expr
Type - Represents type of an expression.
- GetGlobal
Error - Error returned when a global variable access encounters a type or shape mismatch.
- Global
DefKind - Kind of a pre-defined global variable.
- Repeated
Type Syntax - Specifies the type constraints for a repeated parameter.
- Singular
ArgSyntax - Syntax specification for a non-repeated argument.
- Stop
Reason - Representation of termination states from program execution.
- Upcall
Error - Error type for uncaught upcall failures.
- VarArg
Tag - Tags used as integer register values to identify the type stored in another register at runtime.
Traits
- Callable
- A trait to define a callable that is executed by a
Machine.
Functions
- only_
metadata - Extracts the metadata of all provided
upcalls.
Type Aliases
- Call
Result - Result type for callable execution.
- GetGlobal
Result - Result type for global variable access operations.