pub struct BuiltinCallISpan {
pub name: SymbolKey,
pub name_pos: LineCol,
pub upcall_index: usize,
pub nargs: usize,
}Expand description
Components of a builtin command call.
Fields
name: SymbolKeyName of the builtin to call.
name_pos: LineColPosition of the name.
upcall_index: usizeRuntime index to execute this call.
nargs: usizeNumber of arguments on the stack for the call.
The arguments in the stack are interspersed with the separators used to separate them from each other because those separators have meaning.